Endpoint class

Constructors

Endpoint({required String path, required HttpMethod method, ResponseType responseType = ResponseType.json, dynamic parameters, Map<String, dynamic>? queryParameters, bool rawPath = false, Map<String, dynamic>? headers, bool? forceMock})

Properties

forceMock bool?
This is force to use a mockStrategy if it exists
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, dynamic>?
final
method HttpMethod
final
parameters → dynamic
final
path String
final
queryParameters Map<String, dynamic>?
final
rawPath bool
final
responseType ResponseType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited