ApiError class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ApiError({required String message, required int statusCode, List<Map<String, dynamic>>? errors})
const
ApiError.fromJson(Map<String, dynamic> json)
factory
ApiError.internalError()
factory

Properties

errors List<Map<String, dynamic>>?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

map<T>({T onSuccess(Success success)?, T onError(ApiError error)?}) → T
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited