Success class

Inheritance

Constructors

Success({dynamic data, int? statusCode})
const

Properties

data → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

map<T>({T onSuccess(Success success)?, T onError(ApiError error)?}) → T
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited