NetworkProvider class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
Endpoint endpoints) → Future< NetworkResponse> -
get(
Endpoint endpoints) → Future< NetworkResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
Endpoint endpoints) → Future< NetworkResponse> -
post(
Endpoint endpoints) → Future< NetworkResponse> -
put(
Endpoint endpoints) → Future< NetworkResponse> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited